@@ -5,36 +5,41 @@ import httpx
 
 from ... import errors
 from ...client import AuthenticatedClient, Client
+from ...models.get_capture_response_200 import GetCaptureResponse200
 from ...types import Response
 
 
 def _get_kwargs(
     workspace: str,
-    path: str,
+    id: int,
 ) -> Dict[str, Any]:
     pass
 
     return {
         "method": "get",
-        "url": "/w/{workspace}/capture/{path}".format(
+        "url": "/w/{workspace}/capture/{id}".format(
             workspace=workspace,
-            path=path,
+            id=id,
         ),
     }
 
 
-def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[GetCaptureResponse200]:
     if response.status_code == HTTPStatus.OK:
-        return None
-    if response.status_code == HTTPStatus.NOT_FOUND:
-        return None
+        response_200 = GetCaptureResponse200.from_dict(response.json())
+
+        return response_200
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
         return None
 
 
-def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[GetCaptureResponse200]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -45,27 +50,27 @@ def _build_response(*, client: Union[AuthenticatedClient, Client], response: htt
 
 def sync_detailed(
     workspace: str,
-    path: str,
+    id: int,
     *,
     client: Union[AuthenticatedClient, Client],
-) -> Response[Any]:
-    """get flow preview capture
+) -> Response[GetCaptureResponse200]:
+    """get a capture
 
     Args:
         workspace (str):
-        path (str):
+        id (int):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Any]
+        Response[GetCaptureResponse200]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        path=path,
+        id=id,
     )
 
     response = client.get_httpx_client().request(
@@ -75,31 +80,87 @@ def sync_detailed(
     return _build_response(client=client, response=response)
 
 
-async def asyncio_detailed(
+def sync(
     workspace: str,
-    path: str,
+    id: int,
     *,
     client: Union[AuthenticatedClient, Client],
-) -> Response[Any]:
-    """get flow preview capture
+) -> Optional[GetCaptureResponse200]:
+    """get a capture
 
     Args:
         workspace (str):
-        path (str):
+        id (int):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Any]
+        GetCaptureResponse200
+    """
+
+    return sync_detailed(
+        workspace=workspace,
+        id=id,
+        client=client,
+    ).parsed
+
+
+async def asyncio_detailed(
+    workspace: str,
+    id: int,
+    *,
+    client: Union[AuthenticatedClient, Client],
+) -> Response[GetCaptureResponse200]:
+    """get a capture
+
+    Args:
+        workspace (str):
+        id (int):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
+    Returns:
+        Response[GetCaptureResponse200]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
-        path=path,
+        id=id,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
+
+
+async def asyncio(
+    workspace: str,
+    id: int,
+    *,
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[GetCaptureResponse200]:
+    """get a capture
+
+    Args:
+        workspace (str):
+        id (int):
+
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
+    Returns:
+        GetCaptureResponse200
+    """
+
+    return (
+        await asyncio_detailed(
+            workspace=workspace,
+            id=id,
+            client=client,
+        )
+    ).parsed
