@@ -38,7 +38,8 @@ class GetPostgresTriggerResponse200:
         error (Union[Unset, str]):
         last_server_ping (Union[Unset, datetime.datetime]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, GetPostgresTriggerResponse200ErrorHandlerArgs]):
+        error_handler_args (Union[Unset, GetPostgresTriggerResponse200ErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, GetPostgresTriggerResponse200Retry]):
     """
 
