@@ -55,7 +55,7 @@ class ListExtendedJobsResponse200JobsItemType0:
         parent_job (Union[Unset, str]):
         script_path (Union[Unset, str]):
         script_hash (Union[Unset, str]):
-        args (Union[Unset, ListExtendedJobsResponse200JobsItemType0Args]):
+        args (Union[Unset, ListExtendedJobsResponse200JobsItemType0Args]): The arguments to pass to the script or flow
         result (Union[Unset, Any]):
         logs (Union[Unset, str]):
         deleted (Union[Unset, bool]):
