@@ -1,7 +1,9 @@
+import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
@@ -28,6 +30,7 @@ class ListVariableResponse200Item:
         refresh_error (Union[Unset, str]):
         is_linked (Union[Unset, bool]):
         is_refreshed (Union[Unset, bool]):
+        expires_at (Union[Unset, datetime.datetime]):
     """
 
     workspace_id: str
@@ -42,6 +45,7 @@ class ListVariableResponse200Item:
     refresh_error: Union[Unset, str] = UNSET
     is_linked: Union[Unset, bool] = UNSET
     is_refreshed: Union[Unset, bool] = UNSET
+    expires_at: Union[Unset, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -58,6 +62,9 @@ class ListVariableResponse200Item:
         refresh_error = self.refresh_error
         is_linked = self.is_linked
         is_refreshed = self.is_refreshed
+        expires_at: Union[Unset, str] = UNSET
+        if not isinstance(self.expires_at, Unset):
+            expires_at = self.expires_at.isoformat()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -85,6 +92,8 @@ class ListVariableResponse200Item:
             field_dict["is_linked"] = is_linked
         if is_refreshed is not UNSET:
             field_dict["is_refreshed"] = is_refreshed
+        if expires_at is not UNSET:
+            field_dict["expires_at"] = expires_at
 
         return field_dict
 
@@ -117,6 +126,13 @@ class ListVariableResponse200Item:
 
         is_refreshed = d.pop("is_refreshed", UNSET)
 
+        _expires_at = d.pop("expires_at", UNSET)
+        expires_at: Union[Unset, datetime.datetime]
+        if isinstance(_expires_at, Unset):
+            expires_at = UNSET
+        else:
+            expires_at = isoparse(_expires_at)
+
         list_variable_response_200_item = cls(
             workspace_id=workspace_id,
             path=path,
@@ -130,6 +146,7 @@ class ListVariableResponse200Item:
             refresh_error=refresh_error,
             is_linked=is_linked,
             is_refreshed=is_refreshed,
+            expires_at=expires_at,
         )
 
         list_variable_response_200_item.additional_properties = d
