@@ -21,6 +21,7 @@ class UpdateAppJsonBody:
         value (Union[Unset, Any]):
         policy (Union[Unset, UpdateAppJsonBodyPolicy]):
         deployment_message (Union[Unset, str]):
+        custom_path (Union[Unset, str]):
     """
 
     path: Union[Unset, str] = UNSET
@@ -28,6 +29,7 @@ class UpdateAppJsonBody:
     value: Union[Unset, Any] = UNSET
     policy: Union[Unset, "UpdateAppJsonBodyPolicy"] = UNSET
     deployment_message: Union[Unset, str] = UNSET
+    custom_path: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -39,6 +41,7 @@ class UpdateAppJsonBody:
             policy = self.policy.to_dict()
 
         deployment_message = self.deployment_message
+        custom_path = self.custom_path
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -53,6 +56,8 @@ class UpdateAppJsonBody:
             field_dict["policy"] = policy
         if deployment_message is not UNSET:
             field_dict["deployment_message"] = deployment_message
+        if custom_path is not UNSET:
+            field_dict["custom_path"] = custom_path
 
         return field_dict
 
@@ -76,12 +81,15 @@ class UpdateAppJsonBody:
 
         deployment_message = d.pop("deployment_message", UNSET)
 
+        custom_path = d.pop("custom_path", UNSET)
+
         update_app_json_body = cls(
             path=path,
             summary=summary,
             value=value,
             policy=policy,
             deployment_message=deployment_message,
+            custom_path=custom_path,
         )
 
         update_app_json_body.additional_properties = d
