@@ -23,9 +23,16 @@ class WorkerPing:
         wm_version (str):
         last_ping (Union[Unset, float]):
         custom_tags (Union[Unset, List[str]]):
-        current_job_id (Union[Unset, str]):
-        current_job_workspace_id (Union[Unset, str]):
+        last_job_id (Union[Unset, str]):
+        last_job_workspace_id (Union[Unset, str]):
         occupancy_rate (Union[Unset, float]):
+        occupancy_rate_15s (Union[Unset, float]):
+        occupancy_rate_5m (Union[Unset, float]):
+        occupancy_rate_30m (Union[Unset, float]):
+        memory (Union[Unset, float]):
+        vcpus (Union[Unset, float]):
+        memory_usage (Union[Unset, float]):
+        wm_memory_usage (Union[Unset, float]):
     """
 
     worker: str
@@ -37,9 +44,16 @@ class WorkerPing:
     wm_version: str
     last_ping: Union[Unset, float] = UNSET
     custom_tags: Union[Unset, List[str]] = UNSET
-    current_job_id: Union[Unset, str] = UNSET
-    current_job_workspace_id: Union[Unset, str] = UNSET
+    last_job_id: Union[Unset, str] = UNSET
+    last_job_workspace_id: Union[Unset, str] = UNSET
     occupancy_rate: Union[Unset, float] = UNSET
+    occupancy_rate_15s: Union[Unset, float] = UNSET
+    occupancy_rate_5m: Union[Unset, float] = UNSET
+    occupancy_rate_30m: Union[Unset, float] = UNSET
+    memory: Union[Unset, float] = UNSET
+    vcpus: Union[Unset, float] = UNSET
+    memory_usage: Union[Unset, float] = UNSET
+    wm_memory_usage: Union[Unset, float] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -56,9 +70,16 @@ class WorkerPing:
         if not isinstance(self.custom_tags, Unset):
             custom_tags = self.custom_tags
 
-        current_job_id = self.current_job_id
-        current_job_workspace_id = self.current_job_workspace_id
+        last_job_id = self.last_job_id
+        last_job_workspace_id = self.last_job_workspace_id
         occupancy_rate = self.occupancy_rate
+        occupancy_rate_15s = self.occupancy_rate_15s
+        occupancy_rate_5m = self.occupancy_rate_5m
+        occupancy_rate_30m = self.occupancy_rate_30m
+        memory = self.memory
+        vcpus = self.vcpus
+        memory_usage = self.memory_usage
+        wm_memory_usage = self.wm_memory_usage
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -77,12 +98,26 @@ class WorkerPing:
             field_dict["last_ping"] = last_ping
         if custom_tags is not UNSET:
             field_dict["custom_tags"] = custom_tags
-        if current_job_id is not UNSET:
-            field_dict["current_job_id"] = current_job_id
-        if current_job_workspace_id is not UNSET:
-            field_dict["current_job_workspace_id"] = current_job_workspace_id
+        if last_job_id is not UNSET:
+            field_dict["last_job_id"] = last_job_id
+        if last_job_workspace_id is not UNSET:
+            field_dict["last_job_workspace_id"] = last_job_workspace_id
         if occupancy_rate is not UNSET:
             field_dict["occupancy_rate"] = occupancy_rate
+        if occupancy_rate_15s is not UNSET:
+            field_dict["occupancy_rate_15s"] = occupancy_rate_15s
+        if occupancy_rate_5m is not UNSET:
+            field_dict["occupancy_rate_5m"] = occupancy_rate_5m
+        if occupancy_rate_30m is not UNSET:
+            field_dict["occupancy_rate_30m"] = occupancy_rate_30m
+        if memory is not UNSET:
+            field_dict["memory"] = memory
+        if vcpus is not UNSET:
+            field_dict["vcpus"] = vcpus
+        if memory_usage is not UNSET:
+            field_dict["memory_usage"] = memory_usage
+        if wm_memory_usage is not UNSET:
+            field_dict["wm_memory_usage"] = wm_memory_usage
 
         return field_dict
 
@@ -107,12 +142,26 @@ class WorkerPing:
 
         custom_tags = cast(List[str], d.pop("custom_tags", UNSET))
 
-        current_job_id = d.pop("current_job_id", UNSET)
+        last_job_id = d.pop("last_job_id", UNSET)
 
-        current_job_workspace_id = d.pop("current_job_workspace_id", UNSET)
+        last_job_workspace_id = d.pop("last_job_workspace_id", UNSET)
 
         occupancy_rate = d.pop("occupancy_rate", UNSET)
 
+        occupancy_rate_15s = d.pop("occupancy_rate_15s", UNSET)
+
+        occupancy_rate_5m = d.pop("occupancy_rate_5m", UNSET)
+
+        occupancy_rate_30m = d.pop("occupancy_rate_30m", UNSET)
+
+        memory = d.pop("memory", UNSET)
+
+        vcpus = d.pop("vcpus", UNSET)
+
+        memory_usage = d.pop("memory_usage", UNSET)
+
+        wm_memory_usage = d.pop("wm_memory_usage", UNSET)
+
         worker_ping = cls(
             worker=worker,
             worker_instance=worker_instance,
@@ -123,9 +172,16 @@ class WorkerPing:
             wm_version=wm_version,
             last_ping=last_ping,
             custom_tags=custom_tags,
-            current_job_id=current_job_id,
-            current_job_workspace_id=current_job_workspace_id,
+            last_job_id=last_job_id,
+            last_job_workspace_id=last_job_workspace_id,
             occupancy_rate=occupancy_rate,
+            occupancy_rate_15s=occupancy_rate_15s,
+            occupancy_rate_5m=occupancy_rate_5m,
+            occupancy_rate_30m=occupancy_rate_30m,
+            memory=memory,
+            vcpus=vcpus,
+            memory_usage=memory_usage,
+            wm_memory_usage=wm_memory_usage,
         )
 
         worker_ping.additional_properties = d
